@@ -1,4 +1,5 @@
 from typing import Dict
+import requests as r
 
 
 def format_header_string(header_string: str) -> Dict[str, str]:
@@ -10,3 +11,11 @@ def format_header_string(header_string: str) -> Dict[str, str]:
         if key.strip():
             header_dict[key.strip()] = value.strip()
     return header_dict
+
+
+def get_requests_session() -> r.Session:
+    session = r.Session()
+    session.hooks = {
+        "response": lambda response, *args, **kwargs: response.raise_for_status()
+    }
+    return session
